==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/KwalifikacjaPielegniarska.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class KwalifikacjaPielegniarska extends GenericDPSObject {
    /**
     * KWALIFIKACJA_PIELEGNIARSKA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.OCENA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ocenaId;

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.OPIEKA_DLUGOTERMINOWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean opiekaDlugoterminowa;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KWALIFIKACJA_PIELEGNIARSKA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KWALIFIKACJA_PIELEGNIARSKA.OCENA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOcenaId() {
        return ocenaId;
    }

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.OCENA_ID
     *
     * @param ocenaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOcenaId(Long ocenaId) {
        this.ocenaId = ocenaId;
    }

    /**
     * @return KWALIFIKACJA_PIELEGNIARSKA.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return KWALIFIKACJA_PIELEGNIARSKA.OPIEKA_DLUGOTERMINOWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getOpiekaDlugoterminowa() {
        return opiekaDlugoterminowa;
    }

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.OPIEKA_DLUGOTERMINOWA
     *
     * @param opiekaDlugoterminowa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpiekaDlugoterminowa(Boolean opiekaDlugoterminowa) {
        this.opiekaDlugoterminowa = opiekaDlugoterminowa;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KwalifikacjaPielegniarska other = (KwalifikacjaPielegniarska) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOcenaId() == null ? other.getOcenaId() == null : this.getOcenaId().equals(other.getOcenaId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getOpiekaDlugoterminowa() == null ? other.getOpiekaDlugoterminowa() == null : this.getOpiekaDlugoterminowa().equals(other.getOpiekaDlugoterminowa()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOcenaId() == null) ? 0 : getOcenaId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getOpiekaDlugoterminowa() == null) ? 0 : getOpiekaDlugoterminowa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ocenaId=").append(ocenaId);
        sb.append(", data=").append(data);
        sb.append(", opiekaDlugoterminowa=").append(opiekaDlugoterminowa);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/KwalifikacjaPielegniarska.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class KwalifikacjaPielegniarska extends GenericDPSObject {
    /**
     * KWALIFIKACJA_PIELEGNIARSKA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.OCENA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ocenaId;

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.OPIEKA_DLUGOTERMINOWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean opiekaDlugoterminowa;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KWALIFIKACJA_PIELEGNIARSKA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KWALIFIKACJA_PIELEGNIARSKA.OCENA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOcenaId() {
        return ocenaId;
    }

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.OCENA_ID
     *
     * @param ocenaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOcenaId(Long ocenaId) {
        this.ocenaId = ocenaId;
    }

    /**
     * @return KWALIFIKACJA_PIELEGNIARSKA.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return KWALIFIKACJA_PIELEGNIARSKA.OPIEKA_DLUGOTERMINOWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getOpiekaDlugoterminowa() {
        return opiekaDlugoterminowa;
    }

    /**
     * KWALIFIKACJA_PIELEGNIARSKA.OPIEKA_DLUGOTERMINOWA
     *
     * @param opiekaDlugoterminowa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpiekaDlugoterminowa(Boolean opiekaDlugoterminowa) {
        this.opiekaDlugoterminowa = opiekaDlugoterminowa;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KwalifikacjaPielegniarska other = (KwalifikacjaPielegniarska) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOcenaId() == null ? other.getOcenaId() == null : this.getOcenaId().equals(other.getOcenaId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getOpiekaDlugoterminowa() == null ? other.getOpiekaDlugoterminowa() == null : this.getOpiekaDlugoterminowa().equals(other.getOpiekaDlugoterminowa()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOcenaId() == null) ? 0 : getOcenaId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getOpiekaDlugoterminowa() == null) ? 0 : getOpiekaDlugoterminowa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ocenaId=").append(ocenaId);
        sb.append(", data=").append(data);
        sb.append(", opiekaDlugoterminowa=").append(opiekaDlugoterminowa);
        sb.append("]");
        return sb.toString();
    }
}
